@@ -196,7 +196,7 @@ PyObject *sip_api_invoke_slot(const sipSlot *slot, PyObject *sigargs)
     {
         PyObject *nsa, *xtype, *xvalue, *xtb, *resobj;
 
-        if ((resobj = PyEval_CallObject(sfunc, sa)) != NULL)
+        if ((resobj = PyObject_CallObject(sfunc, sa)) != NULL)
         {
             Py_DECREF(sfunc);
             Py_XDECREF(sref);
